@@ -15,6 +15,7 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/commands/oscommands"
 	"github.com/jesseduffield/lazygit/pkg/commands/types/enums"
 	"github.com/jesseduffield/lazygit/pkg/common"
+	"github.com/samber/lo"
 )
 
 // context:
@@ -28,11 +29,16 @@ type CommitLoader struct {
 	*common.Common
 	cmd oscommands.ICmdObjBuilder
 
-	getCurrentBranchInfo func() (BranchInfo, error)
-	getRebaseMode        func() (enums.RebaseMode, error)
-	readFile             func(filename string) ([]byte, error)
-	walkFiles            func(root string, fn filepath.WalkFunc) error
-	dotGitDir            string
+	getRebaseMode func() (enums.RebaseMode, error)
+	readFile      func(filename string) ([]byte, error)
+	walkFiles     func(root string, fn filepath.WalkFunc) error
+	dotGitDir     string
+	// List of main branches that exist in the repo.
+	// We use these to obtain the merge base of the branch.
+	// When nil, we're yet to obtain the list of existing main branches.
+	// When an empty slice, we've obtained the list and it's empty.
+	mainBranches []string
+	*GitCommon
 }
 
 // making our dependencies explicit for the sake of easier testing
@@ -40,17 +46,18 @@ func NewCommitLoader(
 	cmn *common.Common,
 	cmd oscommands.ICmdObjBuilder,
 	dotGitDir string,
-	getCurrentBranchInfo func() (BranchInfo, error),
 	getRebaseMode func() (enums.RebaseMode, error),
+	gitCommon *GitCommon,
 ) *CommitLoader {
 	return &CommitLoader{
-		Common:               cmn,
-		cmd:                  cmd,
-		getCurrentBranchInfo: getCurrentBranchInfo,
-		getRebaseMode:        getRebaseMode,
-		readFile:             os.ReadFile,
-		walkFiles:            filepath.Walk,
-		dotGitDir:            dotGitDir,
+		Common:        cmn,
+		cmd:           cmd,
+		getRebaseMode: getRebaseMode,
+		readFile:      os.ReadFile,
+		walkFiles:     filepath.Walk,
+		dotGitDir:     dotGitDir,
+		mainBranches:  nil,
+		GitCommon:     gitCommon,
 	}
 }
 
@@ -101,10 +108,7 @@ func (self *CommitLoader) GetCommits(opts GetCommitsOptions) ([]*models.Commit,
 		return commits, nil
 	}
 
-	commits, err = self.setCommitMergedStatuses(opts.RefName, commits)
-	if err != nil {
-		return nil, err
-	}
+	commits = self.setCommitMergedStatuses(opts.RefName, commits)
 
 	return commits, nil
 }
@@ -158,11 +162,17 @@ func (self *CommitLoader) extractCommitFromLine(line string) *models.Commit {
 	tags := []string{}
 
 	if extraInfo != "" {
-		re := regexp.MustCompile(`tag: ([^,\)]+)`)
-		tagMatch := re.FindStringSubmatch(extraInfo)
-		if len(tagMatch) > 1 {
-			tags = append(tags, tagMatch[1])
+		extraInfoFields := strings.Split(extraInfo, ",")
+		for _, extraInfoField := range extraInfoFields {
+			extraInfoField = strings.TrimSpace(extraInfoField)
+			re := regexp.MustCompile(`tag: (.+)`)
+			tagMatch := re.FindStringSubmatch(extraInfoField)
+			if len(tagMatch) > 1 {
+				tags = append(tags, tagMatch[1])
+			}
 		}
+
+		extraInfo = "(" + extraInfo + ")"
 	}
 
 	unitTimestampInt, _ := strconv.Atoi(unixTimestamp)
@@ -201,12 +211,11 @@ func (self *CommitLoader) getHydratedRebasingCommits(rebaseMode enums.RebaseMode
 	// note that we're not filtering these as we do non-rebasing commits just because
 	// I suspect that will cause some damage
 	cmdObj := self.cmd.New(
-		fmt.Sprintf(
-			"git -c log.showSignature=false show %s --no-patch --oneline %s --abbrev=%d",
-			strings.Join(commitShas, " "),
-			prettyFormat,
-			20,
-		),
+		NewGitCmd("show").
+			Config("log.showSignature=false").
+			Arg("--no-patch", "--oneline", "--abbrev=20", prettyFormat).
+			Arg(commitShas...).
+			ToArgv(),
 	).DontLog()
 
 	fullCommits := map[string]*models.Commit{}
@@ -219,11 +228,24 @@ func (self *CommitLoader) getHydratedRebasingCommits(rebaseMode enums.RebaseMode
 		return nil, err
 	}
 
+	findFullCommit := lo.Ternary(self.version.IsOlderThan(2, 25, 2),
+		func(sha string) *models.Commit {
+			for s, c := range fullCommits {
+				if strings.HasPrefix(s, sha) {
+					return c
+				}
+			}
+			return nil
+		},
+		func(sha string) *models.Commit {
+			return fullCommits[sha]
+		})
+
 	hydratedCommits := make([]*models.Commit, 0, len(commits))
 	for _, rebasingCommit := range commits {
 		if rebasingCommit.Sha == "" {
 			hydratedCommits = append(hydratedCommits, rebasingCommit)
-		} else if commit := fullCommits[rebasingCommit.Sha]; commit != nil {
+		} else if commit := findFullCommit(rebasingCommit.Sha); commit != nil {
 			commit.Action = rebasingCommit.Action
 			commit.Status = rebasingCommit.Status
 			hydratedCommits = append(hydratedCommits, commit)
@@ -304,12 +326,23 @@ func (self *CommitLoader) getInteractiveRebasingCommits() ([]*models.Commit, err
 
 	commits := []*models.Commit{}
 
-	todos, err := todo.Parse(bytes.NewBuffer(bytesContent))
+	todos, err := todo.Parse(bytes.NewBuffer(bytesContent), self.config.GetCoreCommentChar())
 	if err != nil {
 		self.Log.Error(fmt.Sprintf("error occurred while parsing git-rebase-todo file: %s", err.Error()))
 		return nil, nil
 	}
 
+	// See if the current commit couldn't be applied because it conflicted; if
+	// so, add a fake entry for it
+	if conflictedCommitSha := self.getConflictedCommit(todos); conflictedCommitSha != "" {
+		commits = append(commits, &models.Commit{
+			Sha:    conflictedCommitSha,
+			Name:   "",
+			Status: models.StatusRebasing,
+			Action: models.ActionConflict,
+		})
+	}
+
 	for _, t := range todos {
 		if t.Command == todo.UpdateRef {
 			t.Msg = strings.TrimPrefix(t.Ref, "refs/heads/")
@@ -328,6 +361,93 @@ func (self *CommitLoader) getInteractiveRebasingCommits() ([]*models.Commit, err
 	return commits, nil
 }
 
+func (self *CommitLoader) getConflictedCommit(todos []todo.Todo) string {
+	bytesContent, err := self.readFile(filepath.Join(self.dotGitDir, "rebase-merge/done"))
+	if err != nil {
+		self.Log.Error(fmt.Sprintf("error occurred reading rebase-merge/done: %s", err.Error()))
+		return ""
+	}
+
+	doneTodos, err := todo.Parse(bytes.NewBuffer(bytesContent), self.config.GetCoreCommentChar())
+	if err != nil {
+		self.Log.Error(fmt.Sprintf("error occurred while parsing rebase-merge/done file: %s", err.Error()))
+		return ""
+	}
+
+	amendFileExists := false
+	if _, err := os.Stat(filepath.Join(self.dotGitDir, "rebase-merge/amend")); err == nil {
+		amendFileExists = true
+	}
+
+	return self.getConflictedCommitImpl(todos, doneTodos, amendFileExists)
+}
+
+func (self *CommitLoader) getConflictedCommitImpl(todos []todo.Todo, doneTodos []todo.Todo, amendFileExists bool) string {
+	// Should never be possible, but just to be safe:
+	if len(doneTodos) == 0 {
+		self.Log.Error("no done entries in rebase-merge/done file")
+		return ""
+	}
+	lastTodo := doneTodos[len(doneTodos)-1]
+	if lastTodo.Command == todo.Break || lastTodo.Command == todo.Exec || lastTodo.Command == todo.Reword {
+		return ""
+	}
+
+	// In certain cases, git reschedules commands that failed. One example is if
+	// a patch would overwrite an untracked file (another one is an "exec" that
+	// failed, but we don't care about that here because we dealt with exec
+	// already above). To detect this, compare the last command of the "done"
+	// file against the first command of "git-rebase-todo"; if they are the
+	// same, the command was rescheduled.
+	if len(doneTodos) > 0 && len(todos) > 0 && doneTodos[len(doneTodos)-1] == todos[0] {
+		// Command was rescheduled, no need to display it
+		return ""
+	}
+
+	// Older versions of git have a bug whereby, if a command is rescheduled,
+	// the last successful command is appended to the "done" file again. To
+	// detect this, we need to compare the second-to-last done entry against the
+	// first todo entry, and also compare the last done entry against the
+	// last-but-two done entry; this latter check is needed for the following
+	// case:
+	//   pick A
+	//   exec make test
+	//   pick B
+	//   exec make test
+	// If pick B fails with conflicts, then the "done" file contains
+	//   pick A
+	//   exec make test
+	//   pick B
+	// and git-rebase-todo contains
+	//   exec make test
+	// Without the last condition we would erroneously treat this as the exec
+	// command being rescheduled, so we wouldn't display our fake entry for
+	// "pick B".
+	if len(doneTodos) >= 3 && len(todos) > 0 && doneTodos[len(doneTodos)-2] == todos[0] &&
+		doneTodos[len(doneTodos)-1] == doneTodos[len(doneTodos)-3] {
+		// Command was rescheduled, no need to display it
+		return ""
+	}
+
+	if lastTodo.Command == todo.Edit {
+		if amendFileExists {
+			// Special case for "edit": if the "amend" file exists, the "edit"
+			// command was successful, otherwise it wasn't
+			return ""
+		}
+	}
+
+	// I don't think this is ever possible, but again, just to be safe:
+	if lastTodo.Commit == "" {
+		self.Log.Error("last command in rebase-merge/done file doesn't have a commit")
+		return ""
+	}
+
+	// Any other todo that has a commit associated with it must have failed with
+	// a conflict, otherwise we wouldn't have stopped the rebase:
+	return lastTodo.Commit
+}
+
 // assuming the file starts like this:
 // From e93d4193e6dd45ca9cf3a5a273d7ba6cd8b8fb20 Mon Sep 17 00:00:00 2001
 // From: Lazygit Tester <test@example.com>
@@ -344,43 +464,82 @@ func (self *CommitLoader) commitFromPatch(content string) *models.Commit {
 	}
 }
 
-func (self *CommitLoader) setCommitMergedStatuses(refName string, commits []*models.Commit) ([]*models.Commit, error) {
-	ancestor, err := self.getMergeBase(refName)
-	if err != nil {
-		return nil, err
-	}
+func (self *CommitLoader) setCommitMergedStatuses(refName string, commits []*models.Commit) []*models.Commit {
+	ancestor := self.getMergeBase(refName)
 	if ancestor == "" {
-		return commits, nil
+		return commits
 	}
 	passedAncestor := false
 	for i, commit := range commits {
 		if strings.HasPrefix(ancestor, commit.Sha) {
 			passedAncestor = true
 		}
-		if commit.Status != models.StatusPushed {
+		if commit.Status != models.StatusPushed && commit.Status != models.StatusUnpushed {
 			continue
 		}
 		if passedAncestor {
 			commits[i].Status = models.StatusMerged
 		}
 	}
-	return commits, nil
+	return commits
 }
 
-func (self *CommitLoader) getMergeBase(refName string) (string, error) {
-	info, err := self.getCurrentBranchInfo()
+func (self *CommitLoader) getMergeBase(refName string) string {
+	if self.mainBranches == nil {
+		self.mainBranches = self.getExistingMainBranches()
+	}
+
+	if len(self.mainBranches) == 0 {
+		return ""
+	}
+
+	// We pass all configured main branches to the merge-base call; git will
+	// return the base commit for the closest one.
+
+	output, err := self.cmd.New(
+		NewGitCmd("merge-base").Arg(refName).Arg(self.mainBranches...).
+			ToArgv(),
+	).DontLog().RunWithOutput()
 	if err != nil {
-		return "", err
+		// If there's an error, it must be because one of the main branches that
+		// used to exist when we called getExistingMainBranches() was deleted
+		// meanwhile. To fix this for next time, throw away our cache.
+		self.mainBranches = nil
 	}
+	return ignoringWarnings(output)
+}
 
-	baseBranch := "master"
-	if strings.HasPrefix(info.RefName, "feature/") {
-		baseBranch = "develop"
-	}
+func (self *CommitLoader) getExistingMainBranches() []string {
+	return lo.FilterMap(self.UserConfig.Git.MainBranches,
+		func(branchName string, _ int) (string, bool) {
+			// Try to determine upstream of local main branch
+			if ref, err := self.cmd.New(
+				NewGitCmd("rev-parse").Arg("--symbolic-full-name", branchName+"@{u}").ToArgv(),
+			).DontLog().RunWithOutput(); err == nil {
+				return strings.TrimSpace(ref), true
+			}
 
-	// swallowing error because it's not a big deal; probably because there are no commits yet
-	output, _ := self.cmd.New(fmt.Sprintf("git merge-base %s %s", self.cmd.Quote(refName), self.cmd.Quote(baseBranch))).DontLog().RunWithOutput()
-	return ignoringWarnings(output), nil
+			// If this failed, a local branch for this main branch doesn't exist or it
+			// has no upstream configured. Try looking for one in the "origin" remote.
+			ref := "refs/remotes/origin/" + branchName
+			if err := self.cmd.New(
+				NewGitCmd("rev-parse").Arg("--verify", "--quiet", ref).ToArgv(),
+			).DontLog().Run(); err == nil {
+				return ref, true
+			}
+
+			// If this failed as well, try if we have the main branch as a local
+			// branch. This covers the case where somebody is using git locally
+			// for something, but never pushing anywhere.
+			ref = "refs/heads/" + branchName
+			if err := self.cmd.New(
+				NewGitCmd("rev-parse").Arg("--verify", "--quiet", ref).ToArgv(),
+			).DontLog().Run(); err == nil {
+				return ref, true
+			}
+
+			return "", false
+		})
 }
 
 func ignoringWarnings(commandOutput string) string {
@@ -396,12 +555,12 @@ func ignoringWarnings(commandOutput string) string {
 // getFirstPushedCommit returns the first commit SHA which has been pushed to the ref's upstream.
 // all commits above this are deemed unpushed and marked as such.
 func (self *CommitLoader) getFirstPushedCommit(refName string) (string, error) {
-	output, err := self.cmd.
-		New(
-			fmt.Sprintf("git merge-base %s %s@{u}",
-				self.cmd.Quote(refName),
-				self.cmd.Quote(strings.TrimPrefix(refName, "refs/heads/"))),
-		).
+	output, err := self.cmd.New(
+		NewGitCmd("merge-base").
+			Arg(refName).
+			Arg(strings.TrimPrefix(refName, "refs/heads/") + "@{u}").
+			ToArgv(),
+	).
 		DontLog().
 		RunWithOutput()
 	if err != nil {
@@ -413,42 +572,23 @@ func (self *CommitLoader) getFirstPushedCommit(refName string) (string, error) {
 
 // getLog gets the git log.
 func (self *CommitLoader) getLogCmd(opts GetCommitsOptions) oscommands.ICmdObj {
-	limitFlag := ""
-	if opts.Limit {
-		limitFlag = " -300"
-	}
-
-	followFlag := ""
-	filterFlag := ""
-	if opts.FilterPath != "" {
-		followFlag = " --follow"
-		filterFlag = fmt.Sprintf(" %s", self.cmd.Quote(opts.FilterPath))
-	}
-
 	config := self.UserConfig.Git.Log
 
-	orderFlag := ""
-	if config.Order != "default" {
-		orderFlag = " --" + config.Order
-	}
-	allFlag := ""
-	if opts.All {
-		allFlag = " --all"
-	}
+	cmdArgs := NewGitCmd("log").
+		Arg(opts.RefName).
+		ArgIf(config.Order != "default", "--"+config.Order).
+		ArgIf(opts.All, "--all").
+		Arg("--oneline").
+		Arg(prettyFormat).
+		Arg("--abbrev=40").
+		ArgIf(opts.Limit, "-300").
+		ArgIf(opts.FilterPath != "", "--follow").
+		Arg("--no-show-signature").
+		Arg("--").
+		ArgIf(opts.FilterPath != "", opts.FilterPath).
+		ToArgv()
 
-	return self.cmd.New(
-		fmt.Sprintf(
-			"git log %s%s%s --oneline %s%s --abbrev=%d%s --no-show-signature --%s",
-			self.cmd.Quote(opts.RefName),
-			orderFlag,
-			allFlag,
-			prettyFormat,
-			limitFlag,
-			40,
-			followFlag,
-			filterFlag,
-		),
-	).DontLog()
+	return self.cmd.New(cmdArgs).DontLog()
 }
 
-const prettyFormat = `--pretty=format:"%H%x00%at%x00%aN%x00%ae%x00%d%x00%p%x00%s"`
+const prettyFormat = `--pretty=format:%H%x00%at%x00%aN%x00%ae%x00%D%x00%p%x00%s`
