@@ -18,3 +18,15 @@ func (self *baseController) GetMouseKeybindings(opts types.KeybindingsOpts) []*g
 func (self *baseController) GetOnClick() func() error {
 	return nil
 }
+
+func (self *baseController) GetOnRenderToMain() func() error {
+	return nil
+}
+
+func (self *baseController) GetOnFocus() func(types.OnFocusOpts) error {
+	return nil
+}
+
+func (self *baseController) GetOnFocusLost() func(types.OnFocusLostOpts) error {
+	return nil
+}
