@@ -8,29 +8,33 @@ import (
 
 type CommitMessageController struct {
 	baseController
-	*controllerCommon
+	c *ControllerCommon
 }
 
 var _ types.IController = &CommitMessageController{}
 
 func NewCommitMessageController(
-	common *controllerCommon,
+	common *ControllerCommon,
 ) *CommitMessageController {
 	return &CommitMessageController{
-		baseController:   baseController{},
-		controllerCommon: common,
+		baseController: baseController{},
+		c:              common,
 	}
 }
 
+// TODO: merge that commit panel PR because we're not currently showing how to add a newline as it's
+// handled by the editor func rather than by the controller here.
 func (self *CommitMessageController) GetKeybindings(opts types.KeybindingsOpts) []*types.Binding {
 	bindings := []*types.Binding{
 		{
-			Key:     opts.GetKey(opts.Config.Universal.SubmitEditorText),
-			Handler: self.confirm,
+			Key:         opts.GetKey(opts.Config.Universal.SubmitEditorText),
+			Handler:     self.confirm,
+			Description: self.c.Tr.Confirm,
 		},
 		{
-			Key:     opts.GetKey(opts.Config.Universal.Return),
-			Handler: self.close,
+			Key:         opts.GetKey(opts.Config.Universal.Return),
+			Handler:     self.close,
+			Description: self.c.Tr.Close,
 		},
 		{
 			Key:     opts.GetKey(opts.Config.Universal.PrevItem),
@@ -49,12 +53,19 @@ func (self *CommitMessageController) GetKeybindings(opts types.KeybindingsOpts)
 	return bindings
 }
 
+func (self *CommitMessageController) GetOnFocusLost() func(types.OnFocusLostOpts) error {
+	return func(types.OnFocusLostOpts) error {
+		self.context().RenderCommitLength()
+		return nil
+	}
+}
+
 func (self *CommitMessageController) Context() types.Context {
 	return self.context()
 }
 
 func (self *CommitMessageController) context() *context.CommitMessageContext {
-	return self.contexts.CommitMessage
+	return self.c.Contexts().CommitMessage
 }
 
 func (self *CommitMessageController) handlePreviousCommit() error {
@@ -69,7 +80,7 @@ func (self *CommitMessageController) handleNextCommit() error {
 }
 
 func (self *CommitMessageController) switchToCommitDescription() error {
-	if err := self.c.PushContext(self.contexts.CommitDescription); err != nil {
+	if err := self.c.PushContext(self.c.Contexts().CommitDescription); err != nil {
 		return err
 	}
 	return nil
@@ -80,10 +91,10 @@ func (self *CommitMessageController) handleCommitIndexChange(value int) error {
 	newIndex := currentIndex + value
 	if newIndex == context.NoCommitIndex {
 		self.context().SetSelectedIndex(newIndex)
-		self.helpers.Commits.SetMessageAndDescriptionInView(self.context().GetHistoryMessage())
+		self.c.Helpers().Commits.SetMessageAndDescriptionInView(self.context().GetHistoryMessage())
 		return nil
 	} else if currentIndex == context.NoCommitIndex {
-		self.context().SetHistoryMessage(self.helpers.Commits.JoinCommitMessageAndDescription())
+		self.context().SetHistoryMessage(self.c.Helpers().Commits.JoinCommitMessageAndDescription())
 	}
 
 	validCommit, err := self.setCommitMessageAtIndex(newIndex)
@@ -95,21 +106,21 @@ func (self *CommitMessageController) handleCommitIndexChange(value int) error {
 
 // returns true if the given index is for a valid commit
 func (self *CommitMessageController) setCommitMessageAtIndex(index int) (bool, error) {
-	commitMessage, err := self.git.Commit.GetCommitMessageFromHistory(index)
+	commitMessage, err := self.c.Git().Commit.GetCommitMessageFromHistory(index)
 	if err != nil {
 		if err == git_commands.ErrInvalidCommitIndex {
 			return false, nil
 		}
 		return false, self.c.ErrorMsg(self.c.Tr.CommitWithoutMessageErr)
 	}
-	self.helpers.Commits.UpdateCommitPanelView(commitMessage)
+	self.c.Helpers().Commits.UpdateCommitPanelView(commitMessage)
 	return true, nil
 }
 
 func (self *CommitMessageController) confirm() error {
-	return self.helpers.Commits.HandleCommitConfirm()
+	return self.c.Helpers().Commits.HandleCommitConfirm()
 }
 
 func (self *CommitMessageController) close() error {
-	return self.helpers.Commits.CloseCommitMessagePanel()
+	return self.c.Helpers().Commits.CloseCommitMessagePanel()
 }
