@@ -4,7 +4,6 @@ import (
 	"strings"
 
 	"github.com/jesseduffield/gocui"
-	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/gui/context"
 	"github.com/jesseduffield/lazygit/pkg/gui/filetree"
@@ -13,23 +12,16 @@ import (
 
 type FilesController struct {
 	baseController // nolint: unused
-	*controllerCommon
-
-	enterSubmodule   func(submodule *models.SubmoduleConfig) error
-	setCommitMessage func(message string)
+	c              *ControllerCommon
 }
 
 var _ types.IController = &FilesController{}
 
 func NewFilesController(
-	common *controllerCommon,
-	enterSubmodule func(submodule *models.SubmoduleConfig) error,
-	setCommitMessage func(message string),
+	common *ControllerCommon,
 ) *FilesController {
 	return &FilesController{
-		controllerCommon: common,
-		enterSubmodule:   enterSubmodule,
-		setCommitMessage: setCommitMessage,
+		c: common,
 	}
 }
 
@@ -38,22 +30,22 @@ func (self *FilesController) GetKeybindings(opts types.KeybindingsOpts) []*types
 		{
 			Key:         opts.GetKey(opts.Config.Universal.Select),
 			Handler:     self.checkSelectedFileNode(self.press),
-			Description: self.c.Tr.LcToggleStaged,
+			Description: self.c.Tr.ToggleStaged,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.OpenStatusFilter),
 			Handler:     self.handleStatusFilterPressed,
-			Description: self.c.Tr.LcFileFilter,
+			Description: self.c.Tr.FileFilter,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.CommitChanges),
-			Handler:     self.helpers.WorkingTree.HandleCommitPress,
+			Handler:     self.c.Helpers().WorkingTree.HandleCommitPress,
 			Description: self.c.Tr.CommitChanges,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.CommitChangesWithoutHook),
-			Handler:     self.helpers.WorkingTree.HandleWIPCommitPress,
-			Description: self.c.Tr.LcCommitChangesWithoutHook,
+			Handler:     self.c.Helpers().WorkingTree.HandleWIPCommitPress,
+			Description: self.c.Tr.CommitChangesWithoutHook,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.AmendLastCommit),
@@ -62,45 +54,45 @@ func (self *FilesController) GetKeybindings(opts types.KeybindingsOpts) []*types
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.CommitChangesWithEditor),
-			Handler:     self.helpers.WorkingTree.HandleCommitEditorPress,
+			Handler:     self.c.Helpers().WorkingTree.HandleCommitEditorPress,
 			Description: self.c.Tr.CommitChangesWithEditor,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.Edit),
 			Handler:     self.checkSelectedFileNode(self.edit),
-			Description: self.c.Tr.LcEditFile,
+			Description: self.c.Tr.EditFile,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.OpenFile),
 			Handler:     self.Open,
-			Description: self.c.Tr.LcOpenFile,
+			Description: self.c.Tr.OpenFile,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.IgnoreFile),
 			Handler:     self.checkSelectedFileNode(self.ignoreOrExcludeMenu),
-			Description: self.c.Tr.Actions.LcIgnoreExcludeFile,
+			Description: self.c.Tr.Actions.IgnoreExcludeFile,
 			OpensMenu:   true,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.RefreshFiles),
 			Handler:     self.refresh,
-			Description: self.c.Tr.LcRefreshFiles,
+			Description: self.c.Tr.RefreshFiles,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.StashAllChanges),
 			Handler:     self.stash,
-			Description: self.c.Tr.LcStashAllChanges,
+			Description: self.c.Tr.StashAllChanges,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.ViewStashOptions),
 			Handler:     self.createStashMenu,
-			Description: self.c.Tr.LcViewStashOptions,
+			Description: self.c.Tr.ViewStashOptions,
 			OpensMenu:   true,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.ToggleStagedAll),
 			Handler:     self.toggleStagedAll,
-			Description: self.c.Tr.LcToggleStagedAll,
+			Description: self.c.Tr.ToggleStagedAll,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Universal.GoInto),
@@ -110,29 +102,29 @@ func (self *FilesController) GetKeybindings(opts types.KeybindingsOpts) []*types
 		{
 			Key:         opts.GetKey(opts.Config.Commits.ViewResetOptions),
 			Handler:     self.createResetToUpstreamMenu,
-			Description: self.c.Tr.LcViewResetToUpstreamOptions,
+			Description: self.c.Tr.ViewResetToUpstreamOptions,
 			OpensMenu:   true,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.ViewResetOptions),
 			Handler:     self.createResetMenu,
-			Description: self.c.Tr.LcViewResetOptions,
+			Description: self.c.Tr.ViewResetOptions,
 			OpensMenu:   true,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.ToggleTreeView),
 			Handler:     self.toggleTreeView,
-			Description: self.c.Tr.LcToggleTreeView,
+			Description: self.c.Tr.ToggleTreeView,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.OpenMergeTool),
-			Handler:     self.helpers.WorkingTree.OpenMergeTool,
-			Description: self.c.Tr.LcOpenMergeTool,
+			Handler:     self.c.Helpers().WorkingTree.OpenMergeTool,
+			Description: self.c.Tr.OpenMergeTool,
 		},
 		{
 			Key:         opts.GetKey(opts.Config.Files.Fetch),
 			Handler:     self.fetch,
-			Description: self.c.Tr.LcFetch,
+			Description: self.c.Tr.Fetch,
 		},
 	}
 }
@@ -172,6 +164,77 @@ func (self *FilesController) GetMouseKeybindings(opts types.KeybindingsOpts) []*
 	}
 }
 
+func (self *FilesController) GetOnRenderToMain() func() error {
+	return func() error {
+		return self.c.Helpers().Diff.WithDiffModeCheck(func() error {
+			node := self.context().GetSelected()
+
+			if node == nil {
+				return self.c.RenderToMainViews(types.RefreshMainOpts{
+					Pair: self.c.MainViewPairs().Normal,
+					Main: &types.ViewUpdateOpts{
+						Title:    self.c.Tr.DiffTitle,
+						SubTitle: self.c.Helpers().Diff.IgnoringWhitespaceSubTitle(),
+						Task:     types.NewRenderStringTask(self.c.Tr.NoChangedFiles),
+					},
+				})
+			}
+
+			if node.File != nil && node.File.HasInlineMergeConflicts {
+				hasConflicts, err := self.c.Helpers().MergeConflicts.SetMergeState(node.GetPath())
+				if err != nil {
+					return err
+				}
+
+				if hasConflicts {
+					return self.c.Helpers().MergeConflicts.Render(false)
+				}
+			}
+
+			self.c.Helpers().MergeConflicts.ResetMergeState()
+
+			pair := self.c.MainViewPairs().Normal
+			if node.File != nil {
+				pair = self.c.MainViewPairs().Staging
+			}
+
+			split := self.c.UserConfig.Gui.SplitDiff == "always" || (node.GetHasUnstagedChanges() && node.GetHasStagedChanges())
+			mainShowsStaged := !split && node.GetHasStagedChanges()
+
+			cmdObj := self.c.Git().WorkingTree.WorktreeFileDiffCmdObj(node, false, mainShowsStaged, self.c.State().GetIgnoreWhitespaceInDiffView())
+			title := self.c.Tr.UnstagedChanges
+			if mainShowsStaged {
+				title = self.c.Tr.StagedChanges
+			}
+			refreshOpts := types.RefreshMainOpts{
+				Pair: pair,
+				Main: &types.ViewUpdateOpts{
+					Task:     types.NewRunPtyTask(cmdObj.GetCmd()),
+					SubTitle: self.c.Helpers().Diff.IgnoringWhitespaceSubTitle(),
+					Title:    title,
+				},
+			}
+
+			if split {
+				cmdObj := self.c.Git().WorkingTree.WorktreeFileDiffCmdObj(node, false, true, self.c.State().GetIgnoreWhitespaceInDiffView())
+
+				title := self.c.Tr.StagedChanges
+				if mainShowsStaged {
+					title = self.c.Tr.UnstagedChanges
+				}
+
+				refreshOpts.Secondary = &types.ViewUpdateOpts{
+					Title:    title,
+					SubTitle: self.c.Helpers().Diff.IgnoringWhitespaceSubTitle(),
+					Task:     types.NewRunPtyTask(cmdObj.GetCmd()),
+				}
+			}
+
+			return self.c.RenderToMainViews(refreshOpts)
+		})
+	}
+}
+
 func (self *FilesController) GetOnClick() func() error {
 	return self.checkSelectedFileNode(self.press)
 }
@@ -227,7 +290,7 @@ func (self *FilesController) optimisticChange(node *filetree.FileNode, optimisti
 	rerender := false
 	err := node.ForEachFile(func(f *models.File) error {
 		// can't act on the file itself: we need to update the original model file
-		for _, modelFile := range self.model.Files {
+		for _, modelFile := range self.c.Model().Files {
 			if modelFile.Name == f.Name {
 				if optimisticChangeFn(modelFile) {
 					rerender = true
@@ -242,7 +305,7 @@ func (self *FilesController) optimisticChange(node *filetree.FileNode, optimisti
 		return err
 	}
 	if rerender {
-		if err := self.c.PostRefreshUpdate(self.contexts.Files); err != nil {
+		if err := self.c.PostRefreshUpdate(self.c.Contexts().Files); err != nil {
 			return err
 		}
 	}
@@ -253,8 +316,8 @@ func (self *FilesController) optimisticChange(node *filetree.FileNode, optimisti
 func (self *FilesController) pressWithLock(node *filetree.FileNode) error {
 	// Obtaining this lock because optimistic rendering requires us to mutate
 	// the files in our model.
-	self.mutexes.RefreshingFilesMutex.Lock()
-	defer self.mutexes.RefreshingFilesMutex.Unlock()
+	self.c.Mutexes().RefreshingFilesMutex.Lock()
+	defer self.c.Mutexes().RefreshingFilesMutex.Unlock()
 
 	if node.IsFile() {
 		file := node.File
@@ -266,7 +329,7 @@ func (self *FilesController) pressWithLock(node *filetree.FileNode) error {
 				return err
 			}
 
-			if err := self.git.WorkingTree.StageFile(file.Name); err != nil {
+			if err := self.c.Git().WorkingTree.StageFile(file.Name); err != nil {
 				return self.c.Error(err)
 			}
 		} else {
@@ -276,7 +339,7 @@ func (self *FilesController) pressWithLock(node *filetree.FileNode) error {
 				return err
 			}
 
-			if err := self.git.WorkingTree.UnStageFile(file.Names(), file.Tracked); err != nil {
+			if err := self.c.Git().WorkingTree.UnStageFile(file.Names(), file.Tracked); err != nil {
 				return self.c.Error(err)
 			}
 		}
@@ -294,7 +357,7 @@ func (self *FilesController) pressWithLock(node *filetree.FileNode) error {
 				return err
 			}
 
-			if err := self.git.WorkingTree.StageFile(node.Path); err != nil {
+			if err := self.c.Git().WorkingTree.StageFile(node.Path); err != nil {
 				return self.c.Error(err)
 			}
 		} else {
@@ -305,7 +368,7 @@ func (self *FilesController) pressWithLock(node *filetree.FileNode) error {
 			}
 
 			// pretty sure it doesn't matter that we're always passing true here
-			if err := self.git.WorkingTree.UnStageFile([]string{node.Path}, true); err != nil {
+			if err := self.c.Git().WorkingTree.UnStageFile([]string{node.Path}, true); err != nil {
 				return self.c.Error(err)
 			}
 		}
@@ -346,7 +409,7 @@ func (self *FilesController) Context() types.Context {
 }
 
 func (self *FilesController) context() *context.WorkingTreeContext {
-	return self.contexts.Files
+	return self.c.Contexts().Files
 }
 
 func (self *FilesController) getSelectedFile() *models.File {
@@ -373,10 +436,10 @@ func (self *FilesController) EnterFile(opts types.OnFocusOpts) error {
 
 	file := node.File
 
-	submoduleConfigs := self.model.Submodules
+	submoduleConfigs := self.c.Model().Submodules
 	if file.IsSubmodule(submoduleConfigs) {
 		submoduleConfig := file.SubmoduleConfig(submoduleConfigs)
-		return self.enterSubmodule(submoduleConfig)
+		return self.c.Helpers().Repos.EnterSubmodule(submoduleConfig)
 	}
 
 	if file.HasInlineMergeConflicts {
@@ -386,7 +449,7 @@ func (self *FilesController) EnterFile(opts types.OnFocusOpts) error {
 		return self.c.ErrorMsg(self.c.Tr.FileStagingRequirements)
 	}
 
-	return self.c.PushContext(self.contexts.Staging, opts)
+	return self.c.PushContext(self.c.Contexts().Staging, opts)
 }
 
 func (self *FilesController) toggleStagedAll() error {
@@ -402,8 +465,8 @@ func (self *FilesController) toggleStagedAll() error {
 }
 
 func (self *FilesController) toggleStagedAllWithLock() error {
-	self.mutexes.RefreshingFilesMutex.Lock()
-	defer self.mutexes.RefreshingFilesMutex.Unlock()
+	self.c.Mutexes().RefreshingFilesMutex.Lock()
+	defer self.c.Mutexes().RefreshingFilesMutex.Unlock()
 
 	root := self.context().FileTreeViewModel.GetRoot()
 
@@ -420,7 +483,7 @@ func (self *FilesController) toggleStagedAllWithLock() error {
 			return err
 		}
 
-		if err := self.git.WorkingTree.StageAll(); err != nil {
+		if err := self.c.Git().WorkingTree.StageAll(); err != nil {
 			return self.c.Error(err)
 		}
 	} else {
@@ -430,7 +493,7 @@ func (self *FilesController) toggleStagedAllWithLock() error {
 			return err
 		}
 
-		if err := self.git.WorkingTree.UnstageAll(); err != nil {
+		if err := self.c.Git().WorkingTree.UnstageAll(); err != nil {
 			return self.c.Error(err)
 		}
 	}
@@ -441,7 +504,7 @@ func (self *FilesController) toggleStagedAllWithLock() error {
 func (self *FilesController) unstageFiles(node *filetree.FileNode) error {
 	return node.ForEachFile(func(file *models.File) error {
 		if file.HasStagedChanges {
-			if err := self.git.WorkingTree.UnStageFile(file.Names(), file.Tracked); err != nil {
+			if err := self.c.Git().WorkingTree.UnStageFile(file.Names(), file.Tracked); err != nil {
 				return err
 			}
 		}
@@ -457,7 +520,7 @@ func (self *FilesController) ignoreOrExcludeTracked(node *filetree.FileNode, trA
 		return err
 	}
 
-	if err := self.git.WorkingTree.RemoveTrackedFiles(node.GetPath()); err != nil {
+	if err := self.c.Git().WorkingTree.RemoveTrackedFiles(node.GetPath()); err != nil {
 		return err
 	}
 
@@ -495,7 +558,7 @@ func (self *FilesController) ignore(node *filetree.FileNode) error {
 	if node.GetPath() == ".gitignore" {
 		return self.c.ErrorMsg(self.c.Tr.Actions.IgnoreFileErr)
 	}
-	err := self.ignoreOrExcludeFile(node, self.c.Tr.IgnoreTracked, self.c.Tr.IgnoreTrackedPrompt, self.c.Tr.Actions.LcIgnoreExcludeFile, self.git.WorkingTree.Ignore)
+	err := self.ignoreOrExcludeFile(node, self.c.Tr.IgnoreTracked, self.c.Tr.IgnoreTrackedPrompt, self.c.Tr.Actions.IgnoreExcludeFile, self.c.Git().WorkingTree.Ignore)
 	if err != nil {
 		return err
 	}
@@ -512,7 +575,7 @@ func (self *FilesController) exclude(node *filetree.FileNode) error {
 		return self.c.ErrorMsg(self.c.Tr.Actions.ExcludeGitIgnoreErr)
 	}
 
-	err := self.ignoreOrExcludeFile(node, self.c.Tr.ExcludeTracked, self.c.Tr.ExcludeTrackedPrompt, self.c.Tr.Actions.ExcludeFile, self.git.WorkingTree.Exclude)
+	err := self.ignoreOrExcludeFile(node, self.c.Tr.ExcludeTracked, self.c.Tr.ExcludeTrackedPrompt, self.c.Tr.Actions.ExcludeFile, self.c.Git().WorkingTree.Exclude)
 	if err != nil {
 		return err
 	}
@@ -521,10 +584,10 @@ func (self *FilesController) exclude(node *filetree.FileNode) error {
 
 func (self *FilesController) ignoreOrExcludeMenu(node *filetree.FileNode) error {
 	return self.c.Menu(types.CreateMenuOptions{
-		Title: self.c.Tr.Actions.LcIgnoreExcludeFile,
+		Title: self.c.Tr.Actions.IgnoreExcludeFile,
 		Items: []*types.MenuItem{
 			{
-				LabelColumns: []string{self.c.Tr.LcIgnoreFile},
+				LabelColumns: []string{self.c.Tr.IgnoreFile},
 				OnPress: func() error {
 					if err := self.ignore(node); err != nil {
 						return self.c.Error(err)
@@ -534,7 +597,7 @@ func (self *FilesController) ignoreOrExcludeMenu(node *filetree.FileNode) error
 				Key: 'i',
 			},
 			{
-				LabelColumns: []string{self.c.Tr.LcExcludeFile},
+				LabelColumns: []string{self.c.Tr.ExcludeFile},
 				OnPress: func() error {
 					if err := self.exclude(node); err != nil {
 						return self.c.Error(err)
@@ -552,19 +615,19 @@ func (self *FilesController) refresh() error {
 }
 
 func (self *FilesController) handleAmendCommitPress() error {
-	if len(self.model.Files) == 0 {
+	if len(self.c.Model().Files) == 0 {
 		return self.c.ErrorMsg(self.c.Tr.NoFilesStagedTitle)
 	}
 
-	if !self.helpers.WorkingTree.AnyStagedFiles() {
-		return self.helpers.WorkingTree.PromptToStageAllAndRetry(self.handleAmendCommitPress)
+	if !self.c.Helpers().WorkingTree.AnyStagedFiles() {
+		return self.c.Helpers().WorkingTree.PromptToStageAllAndRetry(self.handleAmendCommitPress)
 	}
 
-	if len(self.model.Commits) == 0 {
+	if len(self.c.Model().Commits) == 0 {
 		return self.c.ErrorMsg(self.c.Tr.NoCommitToAmend)
 	}
 
-	return self.helpers.AmendHelper.AmendHead()
+	return self.c.Helpers().AmendHelper.AmendHead()
 }
 
 func (self *FilesController) handleStatusFilterPressed() error {
@@ -584,7 +647,7 @@ func (self *FilesController) handleStatusFilterPressed() error {
 				},
 			},
 			{
-				Label: self.c.Tr.ResetCommitFilterState,
+				Label: self.c.Tr.ResetFilter,
 				OnPress: func() error {
 					return self.setStatusFiltering(filetree.DisplayAll)
 				},
@@ -594,7 +657,7 @@ func (self *FilesController) handleStatusFilterPressed() error {
 }
 
 func (self *FilesController) setStatusFiltering(filter filetree.FileTreeDisplayFilter) error {
-	self.context().FileTreeViewModel.SetFilter(filter)
+	self.context().FileTreeViewModel.SetStatusFilter(filter)
 	return self.c.PostRefreshUpdate(self.context())
 }
 
@@ -603,7 +666,7 @@ func (self *FilesController) edit(node *filetree.FileNode) error {
 		return self.c.ErrorMsg(self.c.Tr.ErrCannotEditDirectory)
 	}
 
-	return self.helpers.Files.EditFile(node.GetPath())
+	return self.c.Helpers().Files.EditFile(node.GetPath())
 }
 
 func (self *FilesController) Open() error {
@@ -612,7 +675,7 @@ func (self *FilesController) Open() error {
 		return nil
 	}
 
-	return self.helpers.Files.OpenFile(node.GetPath())
+	return self.c.Helpers().Files.OpenFile(node.GetPath())
 }
 
 func (self *FilesController) switchToMerge() error {
@@ -621,63 +684,63 @@ func (self *FilesController) switchToMerge() error {
 		return nil
 	}
 
-	return self.helpers.MergeConflicts.SwitchToMerge(file.Name)
+	return self.c.Helpers().MergeConflicts.SwitchToMerge(file.Name)
 }
 
 func (self *FilesController) createStashMenu() error {
 	return self.c.Menu(types.CreateMenuOptions{
-		Title: self.c.Tr.LcStashOptions,
+		Title: self.c.Tr.StashOptions,
 		Items: []*types.MenuItem{
 			{
-				Label: self.c.Tr.LcStashAllChanges,
+				Label: self.c.Tr.StashAllChanges,
 				OnPress: func() error {
-					if !self.helpers.WorkingTree.IsWorkingTreeDirty() {
+					if !self.c.Helpers().WorkingTree.IsWorkingTreeDirty() {
 						return self.c.ErrorMsg(self.c.Tr.NoFilesToStash)
 					}
-					return self.handleStashSave(self.git.Stash.Save, self.c.Tr.Actions.StashAllChanges)
+					return self.handleStashSave(self.c.Git().Stash.Push, self.c.Tr.Actions.StashAllChanges)
 				},
 				Key: 'a',
 			},
 			{
-				Label: self.c.Tr.LcStashAllChangesKeepIndex,
+				Label: self.c.Tr.StashAllChangesKeepIndex,
 				OnPress: func() error {
-					if !self.helpers.WorkingTree.IsWorkingTreeDirty() {
+					if !self.c.Helpers().WorkingTree.IsWorkingTreeDirty() {
 						return self.c.ErrorMsg(self.c.Tr.NoFilesToStash)
 					}
 					// if there are no staged files it behaves the same as Stash.Save
-					return self.handleStashSave(self.git.Stash.StashAndKeepIndex, self.c.Tr.Actions.StashAllChangesKeepIndex)
+					return self.handleStashSave(self.c.Git().Stash.StashAndKeepIndex, self.c.Tr.Actions.StashAllChangesKeepIndex)
 				},
 				Key: 'i',
 			},
 			{
-				Label: self.c.Tr.LcStashIncludeUntrackedChanges,
+				Label: self.c.Tr.StashIncludeUntrackedChanges,
 				OnPress: func() error {
-					return self.handleStashSave(self.git.Stash.StashIncludeUntrackedChanges, self.c.Tr.Actions.StashIncludeUntrackedChanges)
+					return self.handleStashSave(self.c.Git().Stash.StashIncludeUntrackedChanges, self.c.Tr.Actions.StashIncludeUntrackedChanges)
 				},
 				Key: 'U',
 			},
 			{
-				Label: self.c.Tr.LcStashStagedChanges,
+				Label: self.c.Tr.StashStagedChanges,
 				OnPress: func() error {
 					// there must be something in staging otherwise the current implementation mucks the stash up
-					if !self.helpers.WorkingTree.AnyStagedFiles() {
+					if !self.c.Helpers().WorkingTree.AnyStagedFiles() {
 						return self.c.ErrorMsg(self.c.Tr.NoTrackedStagedFilesStash)
 					}
-					return self.handleStashSave(self.git.Stash.SaveStagedChanges, self.c.Tr.Actions.StashStagedChanges)
+					return self.handleStashSave(self.c.Git().Stash.SaveStagedChanges, self.c.Tr.Actions.StashStagedChanges)
 				},
 				Key: 's',
 			},
 			{
-				Label: self.c.Tr.LcStashUnstagedChanges,
+				Label: self.c.Tr.StashUnstagedChanges,
 				OnPress: func() error {
-					if !self.helpers.WorkingTree.IsWorkingTreeDirty() {
+					if !self.c.Helpers().WorkingTree.IsWorkingTreeDirty() {
 						return self.c.ErrorMsg(self.c.Tr.NoFilesToStash)
 					}
-					if self.helpers.WorkingTree.AnyStagedFiles() {
-						return self.handleStashSave(self.git.Stash.StashUnstagedChanges, self.c.Tr.Actions.StashUnstagedChanges)
+					if self.c.Helpers().WorkingTree.AnyStagedFiles() {
+						return self.handleStashSave(self.c.Git().Stash.StashUnstagedChanges, self.c.Tr.Actions.StashUnstagedChanges)
 					}
 					// ordinary stash
-					return self.handleStashSave(self.git.Stash.Save, self.c.Tr.Actions.StashUnstagedChanges)
+					return self.handleStashSave(self.c.Git().Stash.Push, self.c.Tr.Actions.StashUnstagedChanges)
 				},
 				Key: 'u',
 			},
@@ -686,11 +749,11 @@ func (self *FilesController) createStashMenu() error {
 }
 
 func (self *FilesController) stash() error {
-	return self.handleStashSave(self.git.Stash.Save, self.c.Tr.Actions.StashAllChanges)
+	return self.handleStashSave(self.c.Git().Stash.Push, self.c.Tr.Actions.StashAllChanges)
 }
 
 func (self *FilesController) createResetToUpstreamMenu() error {
-	return self.helpers.Refs.CreateGitResetMenu("@{upstream}")
+	return self.c.Helpers().Refs.CreateGitResetMenu("@{upstream}")
 }
 
 func (self *FilesController) handleToggleDirCollapsed() error {
@@ -701,7 +764,7 @@ func (self *FilesController) handleToggleDirCollapsed() error {
 
 	self.context().FileTreeViewModel.ToggleCollapsed(node.GetPath())
 
-	if err := self.c.PostRefreshUpdate(self.contexts.Files); err != nil {
+	if err := self.c.PostRefreshUpdate(self.c.Contexts().Files); err != nil {
 		self.c.Log.Error(err)
 	}
 
@@ -737,17 +800,17 @@ func (self *FilesController) onClickSecondary(opts gocui.ViewMouseBindingOpts) e
 }
 
 func (self *FilesController) fetch() error {
-	return self.c.WithLoaderPanel(self.c.Tr.FetchWait, func() error {
-		if err := self.fetchAux(); err != nil {
+	return self.c.WithLoaderPanel(self.c.Tr.FetchWait, func(task gocui.Task) error {
+		if err := self.fetchAux(task); err != nil {
 			_ = self.c.Error(err)
 		}
 		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
 	})
 }
 
-func (self *FilesController) fetchAux() (err error) {
+func (self *FilesController) fetchAux(task gocui.Task) (err error) {
 	self.c.LogAction("Fetch")
-	err = self.git.Sync.Fetch(git_commands.FetchOptions{})
+	err = self.c.Git().Sync.Fetch(task)
 
 	if err != nil && strings.Contains(err.Error(), "exit status 128") {
 		_ = self.c.ErrorMsg(self.c.Tr.PassUnameWrong)
