@@ -4,6 +4,7 @@ import (
 	"github.com/jesseduffield/generics/slices"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
 	"github.com/jesseduffield/lazygit/pkg/gui/presentation/icons"
+	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/theme"
 )
 
@@ -24,6 +25,7 @@ func getTagDisplayStrings(t *models.Tag, diffed bool) []string {
 	if icons.IsIconEnabled() {
 		res = append(res, textStyle.Sprint(icons.IconForTag(t)))
 	}
-	res = append(res, textStyle.Sprint(t.Name))
+	descriptionColor := style.FgYellow
+	res = append(res, textStyle.Sprint(t.Name), descriptionColor.Sprint(t.Description()))
 	return res
 }
