@@ -19,10 +19,16 @@ import (
 // to get the test's name via it's file's path.
 const unitTestDescription = "test test"
 
+const (
+	defaultWidth  = 100
+	defaultHeight = 100
+)
+
 type IntegrationTest struct {
 	name         string
 	description  string
-	extraCmdArgs string
+	extraCmdArgs []string
+	extraEnvVars map[string]string
 	skip         bool
 	setupRepo    func(shell *Shell)
 	setupConfig  func(config *config.AppConfig)
@@ -31,6 +37,8 @@ type IntegrationTest struct {
 		keys config.KeybindingConfig,
 	)
 	gitVersion GitVersionRestriction
+	width      int
+	height     int
 }
 
 var _ integrationTypes.IntegrationTest = &IntegrationTest{}
@@ -45,11 +53,17 @@ type NewIntegrationTestArgs struct {
 	// runs the test
 	Run func(t *TestDriver, keys config.KeybindingConfig)
 	// additional args passed to lazygit
-	ExtraCmdArgs string
+	ExtraCmdArgs []string
 	// for when a test is flakey
-	Skip bool
+	ExtraEnvVars map[string]string
+	Skip         bool
 	// to run a test only on certain git versions
 	GitVersion GitVersionRestriction
+	// width and height when running in headless mode, for testing
+	// the UI in different sizes.
+	// If these are set, the test must be run in headless mode
+	Width  int
+	Height int
 }
 
 type GitVersionRestriction struct {
@@ -112,11 +126,14 @@ func NewIntegrationTest(args NewIntegrationTestArgs) *IntegrationTest {
 		name:         name,
 		description:  args.Description,
 		extraCmdArgs: args.ExtraCmdArgs,
+		extraEnvVars: args.ExtraEnvVars,
 		skip:         args.Skip,
 		setupRepo:    args.SetupRepo,
 		setupConfig:  args.SetupConfig,
 		run:          args.Run,
 		gitVersion:   args.GitVersion,
+		width:        args.Width,
+		height:       args.Height,
 	}
 }
 
@@ -128,10 +145,14 @@ func (self *IntegrationTest) Description() string {
 	return self.description
 }
 
-func (self *IntegrationTest) ExtraCmdArgs() string {
+func (self *IntegrationTest) ExtraCmdArgs() []string {
 	return self.extraCmdArgs
 }
 
+func (self *IntegrationTest) ExtraEnvVars() map[string]string {
+	return self.extraEnvVars
+}
+
 func (self *IntegrationTest) Skip() bool {
 	return self.skip
 }
@@ -165,6 +186,18 @@ func (self *IntegrationTest) Run(gui integrationTypes.GuiDriver) {
 	}
 }
 
+func (self *IntegrationTest) HeadlessDimensions() (int, int) {
+	if self.width == 0 && self.height == 0 {
+		return defaultWidth, defaultHeight
+	}
+
+	return self.width, self.height
+}
+
+func (self *IntegrationTest) RequiresHeadless() bool {
+	return self.width != 0 && self.height != 0
+}
+
 func testNameFromCurrentFilePath() string {
 	path := utils.FilePath(3)
 	return TestNameFromFilePath(path)
