@@ -7,16 +7,16 @@ import (
 
 var Rename = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Try to rename the stash.",
-	ExtraCmdArgs: "",
+	ExtraCmdArgs: []string{},
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
 		shell.
 			EmptyCommit("blah").
 			CreateFileAndAdd("file-1", "change to stash1").
-			StashWithMessage("foo").
+			Stash("foo").
 			CreateFileAndAdd("file-2", "change to stash2").
-			StashWithMessage("bar")
+			Stash("bar")
 	},
 	Run: func(t *TestDriver, keys config.KeybindingConfig) {
 		t.Views().Stash().
